# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/spqr/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/spqr/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.spqr.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.spqr.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.spqr.v1 import config_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_config__pb2
from yandex.cloud.mdb.spqr.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_database__pb2
from yandex.cloud.mdb.spqr.v1 import host_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_host__pb2
from yandex.cloud.mdb.spqr.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_user__pb2
from yandex.cloud.mdb.spqr.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_maintenance__pb2
from yandex.cloud.mdb.spqr.v1 import shard_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_shard__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/mdb/spqr/v1/cluster_service.proto\x12\x18yandex.cloud.mdb.spqr.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a%yandex/cloud/mdb/spqr/v1/backup.proto\x1a&yandex/cloud/mdb/spqr/v1/cluster.proto\x1a%yandex/cloud/mdb/spqr/v1/config.proto\x1a\'yandex/cloud/mdb/spqr/v1/database.proto\x1a#yandex/cloud/mdb/spqr/v1/host.proto\x1a#yandex/cloud/mdb/spqr/v1/user.proto\x1a*yandex/cloud/mdb/spqr/v1/maintenance.proto\x1a$yandex/cloud/mdb/spqr/v1/shard.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"Y\n\x1bGetClusterAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x08revision\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"d\n\x14ListClustersResponse\x12\x33\n\x08\x63lusters\x18\x01 \x03(\x0b\x32!.yandex.cloud.mdb.spqr.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe8\x06\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.mdb.spqr.v1.CreateClusterRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12H\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32-.yandex.cloud.mdb.spqr.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12?\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32$.yandex.cloud.mdb.spqr.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12>\n\x0e\x64\x61tabase_specs\x18\x07 \x03(\x0b\x32&.yandex.cloud.mdb.spqr.v1.DatabaseSpec\x12\x36\n\nuser_specs\x18\x08 \x03(\x0b\x32\".yandex.cloud.mdb.spqr.v1.UserSpec\x12>\n\nhost_specs\x18\t \x03(\x0b\x32\".yandex.cloud.mdb.spqr.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12!\n\nnetwork_id\x18\n \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=150\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x12G\n\x12maintenance_window\x18\r \x01(\x0b\x32+.yandex.cloud.mdb.spqr.v1.MaintenanceWindow\x12\x38\n\x0bshard_specs\x18\x0e \x03(\x0b\x32#.yandex.cloud.mdb.spqr.v1.ShardSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xd0\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12(\n\x04name\x18\x03 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.mdb.spqr.v1.UpdateClusterRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x39\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32$.yandex.cloud.mdb.spqr.v1.ConfigSpec\x12G\n\x12maintenance_window\x18\x07 \x01(\x0b\x32+.yandex.cloud.mdb.spqr.v1.MaintenanceWindow\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12\x1d\n\nnetwork_id\x18\n \x01(\tB\t\x8a\xc8\x31\x05<=150\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xcc\x05\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.mdb.spqr.v1.RestoreClusterRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12H\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32-.yandex.cloud.mdb.spqr.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12?\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32$.yandex.cloud.mdb.spqr.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12>\n\nhost_specs\x18\x07 \x03(\x0b\x32\".yandex.cloud.mdb.spqr.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12!\n\nnetwork_id\x18\x08 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=150\x12\x1b\n\tfolder_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x12(\n\x04time\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0etime_inclusive\x18\x0e \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\n\x10\x0b\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xc9\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x64\n\x0freschedule_type\x18\x02 \x01(\x0e\x32\x45.yandex.cloud.mdb.spqr.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"l\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x04\"\xad\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x07message\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.mdb.spqr.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf2\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12R\n\x0cservice_type\x18\x03 \x01(\x0e\x32<.yandex.cloud.mdb.spqr.v1.ListClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x08 \x01(\x08\x12\x1a\n\x06\x66ilter\x18\t \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x10\n\x08order_by\x18\n \x01(\t\"c\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPOSTGRESQL\x10\x01\x12\n\n\x06ROUTER\x10\x02\x12\x0f\n\x0b\x43OORDINATOR\x10\x03\x12\t\n\x05INFRA\x10\x04\"e\n\x17ListClusterLogsResponse\x12\x31\n\x04logs\x18\x01 \x03(\x0b\x32#.yandex.cloud.mdb.spqr.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"a\n\x0fStreamLogRecord\x12\x33\n\x06record\x18\x01 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\xa7\x03\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12T\n\x0cservice_type\x18\x03 \x01(\x0e\x32>.yandex.cloud.mdb.spqr.v1.StreamClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"c\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPOSTGRESQL\x10\x01\x12\n\n\x06ROUTER\x10\x02\x12\x0f\n\x0b\x43OORDINATOR\x10\x03\x12\t\n\x05INFRA\x10\x04\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8d\x01\n\x10\x42\x61\x63kupListFilter\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13retention_policy_id\x18\x03 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"h\n\x1aListClusterBackupsResponse\x12\x31\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32 .yandex.cloud.mdb.spqr.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe9\x07\n\x08SpqrSpec\x12\x39\n\x06router\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.spqr.v1.SpqrSpec.Router\x12\x43\n\x0b\x63oordinator\x18\x02 \x01(\x0b\x32..yandex.cloud.mdb.spqr.v1.SpqrSpec.Coordinator\x12\x41\n\npostgresql\x18\x03 \x01(\x0b\x32-.yandex.cloud.mdb.spqr.v1.SpqrSpec.PostgreSQL\x12\x37\n\x05infra\x18\x05 \x01(\x0b\x32(.yandex.cloud.mdb.spqr.v1.SpqrSpec.Infra\x12\x18\n\x10\x63onsole_password\x18\x06 \x01(\t\x12\x35\n\tlog_level\x18\x07 \x01(\x0e\x32\".yandex.cloud.mdb.spqr.v1.LogLevel\x12<\n\x08\x62\x61lancer\x18\x08 \x01(\x0b\x32*.yandex.cloud.mdb.spqr.v1.BalancerSettings\x1az\n\x06Router\x12\x38\n\x06\x63onfig\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.spqr.v1.RouterSettings\x12\x36\n\tresources\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\x1a\x84\x01\n\x0b\x43oordinator\x12=\n\x06\x63onfig\x18\x01 \x01(\x0b\x32-.yandex.cloud.mdb.spqr.v1.CoordinatorSettings\x12\x36\n\tresources\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\x1a\x82\x01\n\nPostgreSQL\x12<\n\x06\x63onfig\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.spqr.v1.PostgreSQLSettings\x12\x36\n\tresources\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\x1a\xc3\x01\n\x05Infra\x12\x36\n\tresources\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\x12\x38\n\x06router\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.spqr.v1.RouterSettings\x12\x42\n\x0b\x63oordinator\x18\x04 \x01(\x0b\x32-.yandex.cloud.mdb.spqr.v1.CoordinatorSettingsJ\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05\"\x99\x02\n\nConfigSpec\x12\x35\n\tspqr_spec\x18\x01 \x01(\x0b\x32\".yandex.cloud.mdb.spqr.v1.SpqrSpec\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12>\n\x19\x62\x61\x63kup_retain_period_days\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x06\x61\x63\x63\x65ss\x18\x04 \x01(\x0b\x32 .yandex.cloud.mdb.spqr.v1.Access\x12-\n\tsox_audit\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x9d\x01\n!ListClusterHostsAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x18\n\x08revision\x18\x04 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"b\n\x18ListClusterHostsResponse\x12-\n\x05hosts\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.mdb.spqr.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x16\x41\x64\x64\x43lusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12=\n\nhost_specs\x18\x02 \x03(\x0b\x32\".yandex.cloud.mdb.spqr.v1.HostSpecB\x05\x82\xc8\x31\x01\x31\"A\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\x89\x01\n\x19UpdateClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12J\n\x11update_host_specs\x18\x02 \x03(\x0b\x32(.yandex.cloud.mdb.spqr.v1.UpdateHostSpecB\x05\x82\xc8\x31\x01\x31\"D\n\x1aUpdateClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"t\n\x0eUpdateHostSpec\x12\x17\n\thost_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\"a\n\x19\x44\x65leteClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\"\n\nhost_names\x18\x02 \x03(\tB\x0e\x82\xc8\x31\x01\x31\x8a\xc8\x31\x05<=253\"D\n\x1a\x44\x65leteClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\\\n\x13ResetupHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\">\n\x14ResetupHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"n\n\x16GetClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"z\n\x18ListClusterShardsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x9e\x01\n\"ListClusterShardsAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x18\n\x08revision\x18\x04 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"e\n\x19ListClusterShardsResponse\x12/\n\x06shards\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.mdb.spqr.v1.Shard\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x85\x01\n\x16\x41\x64\x64\x43lusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12=\n\nshard_spec\x18\x04 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.ShardSpecB\x04\xe8\xc7\x31\x01J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"A\n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"}\n\x19\x44\x65leteClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\nshard_name\x18\x02 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a^[a-zA-Z0-9][a-zA-Z0-9-]*$\x8a\xc8\x31\x04<=63\"D\n\x1a\x44\x65leteClusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"\xad\x01\n\x14\x41\x64\x64SubclusterRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12=\n\nhost_specs\x18\x02 \x03(\x0b\x32\".yandex.cloud.mdb.spqr.v1.HostSpecB\x05\x82\xc8\x31\x01\x31\x12<\n\tresources\x18\x03 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.ResourcesB\x04\xe8\xc7\x31\x01\x32\xf8(\n\x0e\x43lusterService\x12\x85\x01\n\x03Get\x12+.yandex.cloud.mdb.spqr.v1.GetClusterRequest\x1a!.yandex.cloud.mdb.spqr.v1.Cluster\".\x82\xd3\xe4\x93\x02(\x12&/managed-spqr/v1/clusters/{cluster_id}\x12\xa4\x01\n\rGetAtRevision\x12\x35.yandex.cloud.mdb.spqr.v1.GetClusterAtRevisionRequest\x1a!.yandex.cloud.mdb.spqr.v1.Cluster\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-spqr/v1/clusters/{cluster_id}:atRevision\x12\x88\x01\n\x04List\x12-.yandex.cloud.mdb.spqr.v1.ListClustersRequest\x1a..yandex.cloud.mdb.spqr.v1.ListClustersResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/managed-spqr/v1/clusters\x12\xa5\x01\n\x06\x43reate\x12..yandex.cloud.mdb.spqr.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1e\"\x19/managed-spqr/v1/clusters:\x01*\x12\xb2\x01\n\x06Update\x12..yandex.cloud.mdb.spqr.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02+2&/managed-spqr/v1/clusters/{cluster_id}:\x01*\x12\xbd\x01\n\x06\x44\x65lete\x12..yandex.cloud.mdb.spqr.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02(*&/managed-spqr/v1/clusters/{cluster_id}\x12\xbf\x01\n\rAddSubcluster\x12..yandex.cloud.mdb.spqr.v1.AddSubclusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*0\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!\"\x1c/managed-spqr/v1/subclusters:\x01*\x12\xb2\x01\n\x05Start\x12-.yandex.cloud.mdb.spqr.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02.\",/managed-spqr/v1/clusters/{cluster_id}:start\x12\xae\x01\n\x04Stop\x12,.yandex.cloud.mdb.spqr.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02-\"+/managed-spqr/v1/clusters/{cluster_id}:stop\x12\xb1\x01\n\x04Move\x12,.yandex.cloud.mdb.spqr.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x30\"+/managed-spqr/v1/clusters/{cluster_id}:move:\x01*\x12\xb6\x01\n\x06\x42\x61\x63kup\x12..yandex.cloud.mdb.spqr.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02/\"-/managed-spqr/v1/clusters/{cluster_id}:backup\x12\xb0\x01\n\x07Restore\x12/.yandex.cloud.mdb.spqr.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"Q\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02&\"!/managed-spqr/v1/clusters:restore:\x01*\x12\xe7\x01\n\x15RescheduleMaintenance\x12\x36.yandex.cloud.mdb.spqr.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x41\"</managed-spqr/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\x12\xa4\x01\n\x08ListLogs\x12\x30.yandex.cloud.mdb.spqr.v1.ListClusterLogsRequest\x1a\x31.yandex.cloud.mdb.spqr.v1.ListClusterLogsResponse\"3\x82\xd3\xe4\x93\x02-\x12+/managed-spqr/v1/clusters/{cluster_id}:logs\x12\xa9\x01\n\nStreamLogs\x12\x32.yandex.cloud.mdb.spqr.v1.StreamClusterLogsRequest\x1a).yandex.cloud.mdb.spqr.v1.StreamLogRecord\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-spqr/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xbc\x01\n\x0eListOperations\x12\x36.yandex.cloud.mdb.spqr.v1.ListClusterOperationsRequest\x1a\x37.yandex.cloud.mdb.spqr.v1.ListClusterOperationsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-spqr/v1/clusters/{cluster_id}/operations\x12\xb0\x01\n\x0bListBackups\x12\x33.yandex.cloud.mdb.spqr.v1.ListClusterBackupsRequest\x1a\x34.yandex.cloud.mdb.spqr.v1.ListClusterBackupsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./managed-spqr/v1/clusters/{cluster_id}/backups\x12\xa8\x01\n\tListHosts\x12\x31.yandex.cloud.mdb.spqr.v1.ListClusterHostsRequest\x1a\x32.yandex.cloud.mdb.spqr.v1.ListClusterHostsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/managed-spqr/v1/clusters/{cluster_id}/hosts\x12\xbc\x01\n\x13ListHostsAtRevision\x12;.yandex.cloud.mdb.spqr.v1.ListClusterHostsAtRevisionRequest\x1a\x32.yandex.cloud.mdb.spqr.v1.ListClusterHostsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/managed-spqr/v1/clusters/{cluster_id}/hosts\x12\xd8\x01\n\x08\x41\x64\x64Hosts\x12\x30.yandex.cloud.mdb.spqr.v1.AddClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"w\xb2\xd2*0\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=\"8/managed-spqr/v1/clusters/{cluster_id}/hosts:batchCreate:\x01*\x12\xe1\x01\n\x0bUpdateHosts\x12\x33.yandex.cloud.mdb.spqr.v1.UpdateClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"z\xb2\xd2*3\n\x1aUpdateClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=\"8/managed-spqr/v1/clusters/{cluster_id}/hosts:batchUpdate:\x01*\x12\xe1\x01\n\x0b\x44\x65leteHosts\x12\x33.yandex.cloud.mdb.spqr.v1.DeleteClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"z\xb2\xd2*3\n\x1a\x44\x65leteClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=\"8/managed-spqr/v1/clusters/{cluster_id}/hosts:batchDelete:\x01*\x12\xd1\x01\n\x0cResetupHosts\x12-.yandex.cloud.mdb.spqr.v1.ResetupHostsRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*-\n\x14ResetupHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x38\"3/managed-spqr/v1/clusters/{cluster_id}:resetupHosts:\x01*\x12\xa1\x01\n\x08GetShard\x12\x30.yandex.cloud.mdb.spqr.v1.GetClusterShardRequest\x1a\x1f.yandex.cloud.mdb.spqr.v1.Shard\"B\x82\xd3\xe4\x93\x02<\x12:/managed-spqr/v1/clusters/{cluster_id}/shards/{shard_name}\x12\xac\x01\n\nListShards\x12\x32.yandex.cloud.mdb.spqr.v1.ListClusterShardsRequest\x1a\x33.yandex.cloud.mdb.spqr.v1.ListClusterShardsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/managed-spqr/v1/clusters/{cluster_id}/shards\x12\xc0\x01\n\x14ListShardsAtRevision\x12<.yandex.cloud.mdb.spqr.v1.ListClusterShardsAtRevisionRequest\x1a\x33.yandex.cloud.mdb.spqr.v1.ListClusterShardsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/managed-spqr/v1/clusters/{cluster_id}/shards\x12\xbd\x01\n\x08\x41\x64\x64Shard\x12\x30.yandex.cloud.mdb.spqr.v1.AddClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2* \n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x05Shard\x82\xd3\xe4\x93\x02\x32\"-/managed-spqr/v1/clusters/{cluster_id}/shards:\x01*\x12\xe0\x01\n\x0b\x44\x65leteShard\x12\x33.yandex.cloud.mdb.spqr.v1.DeleteClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*3\n\x1a\x44\x65leteClusterShardMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<*:/managed-spqr/v1/clusters/{cluster_id}/shards/{shard_name}Ba\n\x1cyandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.spqr.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqr'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCLUSTERATREVISIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERATREVISIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCLUSTERATREVISIONREQUEST'].fields_by_name['revision']._loaded_options = None
  _globals['_GETCLUSTERATREVISIONREQUEST'].fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\005<=150'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\212\3101\005<=150'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\005<=150'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._serialized_options = b'\350\3071\001'
  _globals['_LOGRECORD_MESSAGEENTRY']._loaded_options = None
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST'].fields_by_name['revision']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST'].fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\0011'
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['update_host_specs']._loaded_options = None
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['update_host_specs']._serialized_options = b'\202\3101\0011'
  _globals['_UPDATEHOSTSPEC'].fields_by_name['host_name']._loaded_options = None
  _globals['_UPDATEHOSTSPEC'].fields_by_name['host_name']._serialized_options = b'\350\3071\001'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._serialized_options = b'\202\3101\0011\212\3101\005<=253'
  _globals['_RESETUPHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESETUPHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESETUPHOSTSREQUEST'].fields_by_name['host_names']._loaded_options = None
  _globals['_RESETUPHOSTSREQUEST'].fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST'].fields_by_name['revision']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST'].fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['shard_spec']._loaded_options = None
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['shard_spec']._serialized_options = b'\350\3071\001'
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\032^[a-zA-Z0-9][a-zA-Z0-9-]*$\212\3101\004<=63'
  _globals['_ADDSUBCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDSUBCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _globals['_ADDSUBCLUSTERREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_ADDSUBCLUSTERREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\0011'
  _globals['_ADDSUBCLUSTERREQUEST'].fields_by_name['resources']._loaded_options = None
  _globals['_ADDSUBCLUSTERREQUEST'].fields_by_name['resources']._serialized_options = b'\350\3071\001'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/managed-spqr/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['GetAtRevision']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['GetAtRevision']._serialized_options = b'\202\323\344\223\0023\0221/managed-spqr/v1/clusters/{cluster_id}:atRevision'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/managed-spqr/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\036\"\031/managed-spqr/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002+2&/managed-spqr/v1/clusters/{cluster_id}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002(*&/managed-spqr/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddSubcluster']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddSubcluster']._serialized_options = b'\262\322*0\n\027AddClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002!\"\034/managed-spqr/v1/subclusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\002.\",/managed-spqr/v1/clusters/{cluster_id}:start'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\002-\"+/managed-spqr/v1/clusters/{cluster_id}:stop'
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0020\"+/managed-spqr/v1/clusters/{cluster_id}:move:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\002/\"-/managed-spqr/v1/clusters/{cluster_id}:backup'
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002&\"!/managed-spqr/v1/clusters:restore:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._serialized_options = b'\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster\202\323\344\223\002A\"</managed-spqr/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\002-\022+/managed-spqr/v1/clusters/{cluster_id}:logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._serialized_options = b'\202\323\344\223\0024\0222/managed-spqr/v1/clusters/{cluster_id}:stream_logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0023\0221/managed-spqr/v1/clusters/{cluster_id}/operations'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0020\022./managed-spqr/v1/clusters/{cluster_id}/backups'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\002.\022,/managed-spqr/v1/clusters/{cluster_id}/hosts'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHostsAtRevision']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHostsAtRevision']._serialized_options = b'\202\323\344\223\002.\022,/managed-spqr/v1/clusters/{cluster_id}/hosts'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._serialized_options = b'\262\322*0\n\027AddClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002=\"8/managed-spqr/v1/clusters/{cluster_id}/hosts:batchCreate:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateHosts']._serialized_options = b'\262\322*3\n\032UpdateClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002=\"8/managed-spqr/v1/clusters/{cluster_id}/hosts:batchUpdate:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._serialized_options = b'\262\322*3\n\032DeleteClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002=\"8/managed-spqr/v1/clusters/{cluster_id}/hosts:batchDelete:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ResetupHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ResetupHosts']._serialized_options = b'\262\322*-\n\024ResetupHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\0028\"3/managed-spqr/v1/clusters/{cluster_id}:resetupHosts:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['GetShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['GetShard']._serialized_options = b'\202\323\344\223\002<\022:/managed-spqr/v1/clusters/{cluster_id}/shards/{shard_name}'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShards']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShards']._serialized_options = b'\202\323\344\223\002/\022-/managed-spqr/v1/clusters/{cluster_id}/shards'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShardsAtRevision']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShardsAtRevision']._serialized_options = b'\202\323\344\223\002/\022-/managed-spqr/v1/clusters/{cluster_id}/shards'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddShard']._serialized_options = b'\262\322* \n\027AddClusterShardMetadata\022\005Shard\202\323\344\223\0022\"-/managed-spqr/v1/clusters/{cluster_id}/shards:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShard']._serialized_options = b'\262\322*3\n\032DeleteClusterShardMetadata\022\025google.protobuf.Empty\202\323\344\223\002<*:/managed-spqr/v1/clusters/{cluster_id}/shards/{shard_name}'
  _globals['_GETCLUSTERREQUEST']._serialized_start=654
  _globals['_GETCLUSTERREQUEST']._serialized_end=707
  _globals['_GETCLUSTERATREVISIONREQUEST']._serialized_start=709
  _globals['_GETCLUSTERATREVISIONREQUEST']._serialized_end=798
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=801
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=945
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=947
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=1047
  _globals['_CREATECLUSTERREQUEST']._serialized_start=1050
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1922
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1877
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1922
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1924
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1967
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1970
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2562
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1877
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1922
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2564
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2607
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2609
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2665
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2667
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2710
  _globals['_STARTCLUSTERREQUEST']._serialized_start=2712
  _globals['_STARTCLUSTERREQUEST']._serialized_end=2767
  _globals['_STARTCLUSTERMETADATA']._serialized_start=2769
  _globals['_STARTCLUSTERMETADATA']._serialized_end=2811
  _globals['_STOPCLUSTERREQUEST']._serialized_start=2813
  _globals['_STOPCLUSTERREQUEST']._serialized_end=2867
  _globals['_STOPCLUSTERMETADATA']._serialized_start=2869
  _globals['_STOPCLUSTERMETADATA']._serialized_end=2910
  _globals['_MOVECLUSTERREQUEST']._serialized_start=2912
  _globals['_MOVECLUSTERREQUEST']._serialized_end=3011
  _globals['_MOVECLUSTERMETADATA']._serialized_start=3013
  _globals['_MOVECLUSTERMETADATA']._serialized_end=3111
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=3113
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=3169
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=3171
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=3214
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=3217
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=3933
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=1877
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=1922
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=3935
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=3998
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=4001
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=4330
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_start=4220
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_end=4330
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_start=4332
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_end=4440
  _globals['_LOGRECORD']._serialized_start=4443
  _globals['_LOGRECORD']._serialized_end=4616
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=4570
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=4616
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=4619
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=5117
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=5018
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=5117
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=5119
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=5220
  _globals['_STREAMLOGRECORD']._serialized_start=5222
  _globals['_STREAMLOGRECORD']._serialized_end=5319
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_start=5322
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_end=5745
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=5018
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=5117
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=5747
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=5873
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=5875
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=5986
  _globals['_BACKUPLISTFILTER']._serialized_start=5989
  _globals['_BACKUPLISTFILTER']._serialized_end=6130
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=6132
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=6255
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=6257
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=6361
  _globals['_SPQRSPEC']._serialized_start=6364
  _globals['_SPQRSPEC']._serialized_end=7365
  _globals['_SPQRSPEC_ROUTER']._serialized_start=6771
  _globals['_SPQRSPEC_ROUTER']._serialized_end=6893
  _globals['_SPQRSPEC_COORDINATOR']._serialized_start=6896
  _globals['_SPQRSPEC_COORDINATOR']._serialized_end=7028
  _globals['_SPQRSPEC_POSTGRESQL']._serialized_start=7031
  _globals['_SPQRSPEC_POSTGRESQL']._serialized_end=7161
  _globals['_SPQRSPEC_INFRA']._serialized_start=7164
  _globals['_SPQRSPEC_INFRA']._serialized_end=7359
  _globals['_CONFIGSPEC']._serialized_start=7368
  _globals['_CONFIGSPEC']._serialized_end=7649
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=7651
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=7772
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST']._serialized_start=7775
  _globals['_LISTCLUSTERHOSTSATREVISIONREQUEST']._serialized_end=7932
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=7934
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=8032
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_start=8034
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_end=8155
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_start=8157
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_end=8222
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_start=8225
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_end=8362
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_start=8364
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_end=8432
  _globals['_UPDATEHOSTSPEC']._serialized_start=8434
  _globals['_UPDATEHOSTSPEC']._serialized_end=8550
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_start=8552
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_end=8649
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_start=8651
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_end=8719
  _globals['_RESETUPHOSTSREQUEST']._serialized_start=8721
  _globals['_RESETUPHOSTSREQUEST']._serialized_end=8813
  _globals['_RESETUPHOSTSMETADATA']._serialized_start=8815
  _globals['_RESETUPHOSTSMETADATA']._serialized_end=8877
  _globals['_GETCLUSTERSHARDREQUEST']._serialized_start=8879
  _globals['_GETCLUSTERSHARDREQUEST']._serialized_end=8989
  _globals['_LISTCLUSTERSHARDSREQUEST']._serialized_start=8991
  _globals['_LISTCLUSTERSHARDSREQUEST']._serialized_end=9113
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST']._serialized_start=9116
  _globals['_LISTCLUSTERSHARDSATREVISIONREQUEST']._serialized_end=9274
  _globals['_LISTCLUSTERSHARDSRESPONSE']._serialized_start=9276
  _globals['_LISTCLUSTERSHARDSRESPONSE']._serialized_end=9377
  _globals['_ADDCLUSTERSHARDREQUEST']._serialized_start=9380
  _globals['_ADDCLUSTERSHARDREQUEST']._serialized_end=9513
  _globals['_ADDCLUSTERSHARDMETADATA']._serialized_start=9515
  _globals['_ADDCLUSTERSHARDMETADATA']._serialized_end=9580
  _globals['_DELETECLUSTERSHARDREQUEST']._serialized_start=9582
  _globals['_DELETECLUSTERSHARDREQUEST']._serialized_end=9707
  _globals['_DELETECLUSTERSHARDMETADATA']._serialized_start=9709
  _globals['_DELETECLUSTERSHARDMETADATA']._serialized_end=9777
  _globals['_ADDSUBCLUSTERREQUEST']._serialized_start=9780
  _globals['_ADDSUBCLUSTERREQUEST']._serialized_end=9953
  _globals['_CLUSTERSERVICE']._serialized_start=9956
  _globals['_CLUSTERSERVICE']._serialized_end=15196
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/oauth_client_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/oauth_client_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.iam.v1 import oauth_client_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_oauth__client__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/iam/v1/oauth_client_service.proto\x12\x13yandex.cloud.iam.v1\x1a&yandex/cloud/iam/v1/oauth_client.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\">\n\x15GetOAuthClientRequest\x12%\n\x0foauth_client_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"y\n\x17ListOAuthClientsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1f\n\tfolder_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"t\n\x18ListOAuthClientsResponse\x12?\n\roauth_clients\x18\x01 \x03(\x0b\x32(.yandex.cloud.iam.v1.OAuthClientListView\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"/\n\x13OAuthClientListView\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"4\n\x19UpdateOAuthClientMetadata\x12\x17\n\x0foauth_client_id\x18\x01 \x01(\t\"4\n\x19\x44\x65leteOAuthClientMetadata\x12\x17\n\x0foauth_client_id\x18\x01 \x01(\t\"\xc5\x01\n\x18\x43reateOAuthClientRequest\x12\x35\n\x04name\x18\x01 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12+\n\rredirect_uris\x18\x02 \x03(\tB\x14\x82\xc8\x31\x06<=1000\x8a\xc8\x31\x06<=1000\x12#\n\x06scopes\x18\x03 \x03(\tB\x13\x82\xc8\x31\x06<=1000\x8a\xc8\x31\x05<=255\x12 \n\tfolder_id\x18\x04 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=255\"4\n\x19\x43reateOAuthClientMetadata\x12\x17\n\x0foauth_client_id\x18\x01 \x01(\t\"\xf3\x01\n\x18UpdateOAuthClientRequest\x12\x1d\n\x0foauth_client_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x35\n\x04name\x18\x03 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12+\n\rredirect_uris\x18\x04 \x03(\tB\x14\x82\xc8\x31\x06<=1000\x8a\xc8\x31\x06<=1000\x12#\n\x06scopes\x18\x05 \x03(\tB\x13\x82\xc8\x31\x06<=1000\x8a\xc8\x31\x05<=255\"A\n\x18\x44\x65leteOAuthClientRequest\x12%\n\x0foauth_client_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xc7\x06\n\x12OAuthClientService\x12\x83\x01\n\x03Get\x12*.yandex.cloud.iam.v1.GetOAuthClientRequest\x1a .yandex.cloud.iam.v1.OAuthClient\".\x82\xd3\xe4\x93\x02(\x12&/iam/v1/oauthClients/{oauth_client_id}\x12\x81\x01\n\x04List\x12,.yandex.cloud.iam.v1.ListOAuthClientsRequest\x1a-.yandex.cloud.iam.v1.ListOAuthClientsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/iam/v1/oauthClients\x12\xa7\x01\n\x06\x43reate\x12-.yandex.cloud.iam.v1.CreateOAuthClientRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*(\n\x19\x43reateOAuthClientMetadata\x12\x0bOAuthClient\x82\xd3\xe4\x93\x02\x19\"\x14/iam/v1/oauthClients:\x01*\x12\xb9\x01\n\x06Update\x12-.yandex.cloud.iam.v1.UpdateOAuthClientRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*(\n\x19UpdateOAuthClientMetadata\x12\x0bOAuthClient\x82\xd3\xe4\x93\x02+2&/iam/v1/oauthClients/{oauth_client_id}:\x01*\x12\xc0\x01\n\x06\x44\x65lete\x12-.yandex.cloud.iam.v1.DeleteOAuthClientRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*2\n\x19\x44\x65leteOAuthClientMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02(*&/iam/v1/oauthClients/{oauth_client_id}BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.oauth_client_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_GETOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_GETOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['redirect_uris']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['redirect_uris']._serialized_options = b'\202\3101\006<=1000\212\3101\006<=1000'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['scopes']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['scopes']._serialized_options = b'\202\3101\006<=1000\212\3101\005<=255'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\005<=255'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['redirect_uris']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['redirect_uris']._serialized_options = b'\202\3101\006<=1000\212\3101\006<=1000'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['scopes']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['scopes']._serialized_options = b'\202\3101\006<=1000\212\3101\005<=255'
  _globals['_DELETEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_DELETEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/iam/v1/oauthClients/{oauth_client_id}'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/iam/v1/oauthClients'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateOAuthClientMetadata\022\013OAuthClient\202\323\344\223\002\031\"\024/iam/v1/oauthClients:\001*'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateOAuthClientMetadata\022\013OAuthClient\202\323\344\223\002+2&/iam/v1/oauthClients/{oauth_client_id}:\001*'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteOAuthClientMetadata\022\025google.protobuf.Empty\202\323\344\223\002(*&/iam/v1/oauthClients/{oauth_client_id}'
  _globals['_GETOAUTHCLIENTREQUEST']._serialized_start=280
  _globals['_GETOAUTHCLIENTREQUEST']._serialized_end=342
  _globals['_LISTOAUTHCLIENTSREQUEST']._serialized_start=344
  _globals['_LISTOAUTHCLIENTSREQUEST']._serialized_end=465
  _globals['_LISTOAUTHCLIENTSRESPONSE']._serialized_start=467
  _globals['_LISTOAUTHCLIENTSRESPONSE']._serialized_end=583
  _globals['_OAUTHCLIENTLISTVIEW']._serialized_start=585
  _globals['_OAUTHCLIENTLISTVIEW']._serialized_end=632
  _globals['_UPDATEOAUTHCLIENTMETADATA']._serialized_start=634
  _globals['_UPDATEOAUTHCLIENTMETADATA']._serialized_end=686
  _globals['_DELETEOAUTHCLIENTMETADATA']._serialized_start=688
  _globals['_DELETEOAUTHCLIENTMETADATA']._serialized_end=740
  _globals['_CREATEOAUTHCLIENTREQUEST']._serialized_start=743
  _globals['_CREATEOAUTHCLIENTREQUEST']._serialized_end=940
  _globals['_CREATEOAUTHCLIENTMETADATA']._serialized_start=942
  _globals['_CREATEOAUTHCLIENTMETADATA']._serialized_end=994
  _globals['_UPDATEOAUTHCLIENTREQUEST']._serialized_start=997
  _globals['_UPDATEOAUTHCLIENTREQUEST']._serialized_end=1240
  _globals['_DELETEOAUTHCLIENTREQUEST']._serialized_start=1242
  _globals['_DELETEOAUTHCLIENTREQUEST']._serialized_end=1307
  _globals['_OAUTHCLIENTSERVICE']._serialized_start=1310
  _globals['_OAUTHCLIENTSERVICE']._serialized_end=2149
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.cic.v1.common.lag_allocation_settings_pb2
import yandex.cloud.cic.v1.common.transceiver_type_pb2
import yandex.cloud.cic.v1.trunk_connection_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTrunkConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    trunk_connection_id: builtins.str
    """ID of the TrunkConnection resource to return.
    To get the trunkConnection ID use a [TrunkConnectionService.List] request.
    """
    def __init__(
        self,
        *,
        trunk_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trunk_connection_id", b"trunk_connection_id"]) -> None: ...

global___GetTrunkConnectionRequest = GetTrunkConnectionRequest

@typing.final
class ListTrunkConnectionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list TrunkConnection resources.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListTrunkConnectionsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListTrunkConnectionsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Subnet.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListTrunkConnectionsRequest = ListTrunkConnectionsRequest

@typing.final
class ListTrunkConnectionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUNK_CONNECTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListTrunkConnectionsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListTrunkConnectionsRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def trunk_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection]:
        """List of TrunkConnection resources."""

    def __init__(
        self,
        *,
        trunk_connections: collections.abc.Iterable[yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "trunk_connections", b"trunk_connections"]) -> None: ...

global___ListTrunkConnectionsResponse = ListTrunkConnectionsResponse

@typing.final
class CreateTrunkConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class SinglePortDirectJoint(google.protobuf.message.Message):
        """Config of trunkConnection that is deployed on single port."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRANSCEIVER_TYPE_FIELD_NUMBER: builtins.int
        transceiver_type: yandex.cloud.cic.v1.common.transceiver_type_pb2.TransceiverType.ValueType
        """Type of transceiver that the trunkConnection is deployed on."""
        def __init__(
            self,
            *,
            transceiver_type: yandex.cloud.cic.v1.common.transceiver_type_pb2.TransceiverType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["transceiver_type", b"transceiver_type"]) -> None: ...

    @typing.final
    class LagDirectJoint(google.protobuf.message.Message):
        """Config of trunkConnection that is deployed on lag."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRANSCEIVER_TYPE_FIELD_NUMBER: builtins.int
        LAG_ALLOCATION_SETTINGS_FIELD_NUMBER: builtins.int
        transceiver_type: yandex.cloud.cic.v1.common.transceiver_type_pb2.TransceiverType.ValueType
        """Type of transceiver that the trunkConnection is deployed on."""
        @property
        def lag_allocation_settings(self) -> yandex.cloud.cic.v1.common.lag_allocation_settings_pb2.LagAllocationSettingsRequest:
            """LAG allocation settings that the trunkConnection is deployed on."""

        def __init__(
            self,
            *,
            transceiver_type: yandex.cloud.cic.v1.common.transceiver_type_pb2.TransceiverType.ValueType = ...,
            lag_allocation_settings: yandex.cloud.cic.v1.common.lag_allocation_settings_pb2.LagAllocationSettingsRequest | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["lag_allocation_settings", b"lag_allocation_settings"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["lag_allocation_settings", b"lag_allocation_settings", "transceiver_type", b"transceiver_type"]) -> None: ...

    @typing.final
    class PartnerJoint(google.protobuf.message.Message):
        """Config of trunkConnection that is deployed on partner joint."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PARTNER_ID_FIELD_NUMBER: builtins.int
        @property
        def partner_id(self) -> google.protobuf.wrappers_pb2.StringValue:
            """ID of partner that the trunkConnection is deployed on.
            Optional.
            If is not set scheduler selects it by himself.
            """

        def __init__(
            self,
            *,
            partner_id: google.protobuf.wrappers_pb2.StringValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["partner_id", b"partner_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["partner_id", b"partner_id"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    SINGLE_PORT_DIRECT_JOINT_FIELD_NUMBER: builtins.int
    LAG_DIRECT_JOINT_FIELD_NUMBER: builtins.int
    PARTNER_JOINT_INFO_FIELD_NUMBER: builtins.int
    POINT_OF_PRESENCE_ID_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the trunkConnection.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the trunkConnection. 0-256 characters long."""
    folder_id: builtins.str
    """ID of the folder that the trunkConnection belongs to."""
    region_id: builtins.str
    """ID of the region that the trunkConnection belongs to."""
    capacity: yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection.Capacity.ValueType
    """Capacity of the trunkConnection"""
    deletion_protection: builtins.bool
    """Deletion protection flag.
    Optional.
    If set prohibits deletion of the trunkConnection.
    """
    @property
    def single_port_direct_joint(self) -> global___CreateTrunkConnectionRequest.SinglePortDirectJoint: ...
    @property
    def lag_direct_joint(self) -> global___CreateTrunkConnectionRequest.LagDirectJoint: ...
    @property
    def partner_joint_info(self) -> global___CreateTrunkConnectionRequest.PartnerJoint: ...
    @property
    def point_of_presence_id(self) -> google.protobuf.wrappers_pb2.StringValue:
        """ID of pointOfPresence that the trunkConnection is deployed on.
        Optional.
        If is not set scheduler selects it by himself.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        region_id: builtins.str = ...,
        single_port_direct_joint: global___CreateTrunkConnectionRequest.SinglePortDirectJoint | None = ...,
        lag_direct_joint: global___CreateTrunkConnectionRequest.LagDirectJoint | None = ...,
        partner_joint_info: global___CreateTrunkConnectionRequest.PartnerJoint | None = ...,
        point_of_presence_id: google.protobuf.wrappers_pb2.StringValue | None = ...,
        capacity: yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection.Capacity.ValueType = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["joint", b"joint", "lag_direct_joint", b"lag_direct_joint", "partner_joint_info", b"partner_joint_info", "point_of_presence_id", b"point_of_presence_id", "single_port_direct_joint", b"single_port_direct_joint"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["capacity", b"capacity", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "joint", b"joint", "labels", b"labels", "lag_direct_joint", b"lag_direct_joint", "name", b"name", "partner_joint_info", b"partner_joint_info", "point_of_presence_id", b"point_of_presence_id", "region_id", b"region_id", "single_port_direct_joint", b"single_port_direct_joint"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["joint", b"joint"]) -> typing.Literal["single_port_direct_joint", "lag_direct_joint", "partner_joint_info"] | None: ...

global___CreateTrunkConnectionRequest = CreateTrunkConnectionRequest

@typing.final
class CreateTrunkConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    trunk_connection_id: builtins.str
    """ID of the TrunkConnection resource."""
    def __init__(
        self,
        *,
        trunk_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trunk_connection_id", b"trunk_connection_id"]) -> None: ...

global___CreateTrunkConnectionMetadata = CreateTrunkConnectionMetadata

@typing.final
class UpdateTrunkConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    POINT_OF_PRESENCE_ID_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    trunk_connection_id: builtins.str
    """ID of the TrunkConnection resource to return."""
    name: builtins.str
    """Name of the trunkConnection.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the trunkConnection. 0-256 characters long."""
    region_id: builtins.str
    """ID of the region that the trunkConnection belongs to."""
    capacity: yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection.Capacity.ValueType
    """Capacity of the trunkConnection"""
    deletion_protection: builtins.bool
    """Deletion protection flag.
    Optional.
    If set prohibits deletion of the trunkConnection.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the TrunkConnection resource are going to be updated."""

    @property
    def point_of_presence_id(self) -> google.protobuf.wrappers_pb2.StringValue:
        """ID of pointOfPresence that the trunkConnection is deployed on.
        Optional.
        If is not set scheduler selects it by himself.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        trunk_connection_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        region_id: builtins.str = ...,
        point_of_presence_id: google.protobuf.wrappers_pb2.StringValue | None = ...,
        capacity: yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection.Capacity.ValueType = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["point_of_presence_id", b"point_of_presence_id", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["capacity", b"capacity", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "name", b"name", "point_of_presence_id", b"point_of_presence_id", "region_id", b"region_id", "trunk_connection_id", b"trunk_connection_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateTrunkConnectionRequest = UpdateTrunkConnectionRequest

@typing.final
class UpdateTrunkConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    trunk_connection_id: builtins.str
    """ID of the TrunkConnection resource."""
    def __init__(
        self,
        *,
        trunk_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trunk_connection_id", b"trunk_connection_id"]) -> None: ...

global___UpdateTrunkConnectionMetadata = UpdateTrunkConnectionMetadata

@typing.final
class DeleteTrunkConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    trunk_connection_id: builtins.str
    """ID of the TrunkConnection resource."""
    def __init__(
        self,
        *,
        trunk_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trunk_connection_id", b"trunk_connection_id"]) -> None: ...

global___DeleteTrunkConnectionRequest = DeleteTrunkConnectionRequest

@typing.final
class DeleteTrunkConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    trunk_connection_id: builtins.str
    """ID of the TrunkConnection resource."""
    def __init__(
        self,
        *,
        trunk_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["trunk_connection_id", b"trunk_connection_id"]) -> None: ...

global___DeleteTrunkConnectionMetadata = DeleteTrunkConnectionMetadata

@typing.final
class ListTrunkConnectionOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    trunk_connection_id: builtins.str
    """ID of the TrunkConnection resource."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListTrunkConnectionOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListTrunkConnectionOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        trunk_connection_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "trunk_connection_id", b"trunk_connection_id"]) -> None: ...

global___ListTrunkConnectionOperationsRequest = ListTrunkConnectionOperationsRequest

@typing.final
class ListTrunkConnectionOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListTrunkConnectionOperationsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListTrunkConnectionOperationsRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of TrunkConnection operations."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListTrunkConnectionOperationsResponse = ListTrunkConnectionOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.connectionmanager.v1.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MongoDBAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def user_password(self) -> yandex.cloud.connectionmanager.v1.common_pb2.UserPasswordAuth: ...
    def __init__(
        self,
        *,
        user_password: yandex.cloud.connectionmanager.v1.common_pb2.UserPasswordAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["security", b"security", "user_password", b"user_password"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["security", b"security"]) -> typing.Literal["user_password"] | None: ...

global___MongoDBAuth = MongoDBAuth

@typing.final
class MongoDBCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Host(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Type:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongoDBCluster.Host._Type.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            TYPE_UNSPECIFIED: MongoDBCluster.Host._Type.ValueType  # 0
            MONGOD: MongoDBCluster.Host._Type.ValueType  # 1
            MONGOS: MongoDBCluster.Host._Type.ValueType  # 2
            MONGOINFRA: MongoDBCluster.Host._Type.ValueType  # 3

        class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
        TYPE_UNSPECIFIED: MongoDBCluster.Host.Type.ValueType  # 0
        MONGOD: MongoDBCluster.Host.Type.ValueType  # 1
        MONGOS: MongoDBCluster.Host.Type.ValueType  # 2
        MONGOINFRA: MongoDBCluster.Host.Type.ValueType  # 3

        class _Role:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongoDBCluster.Host._Role.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ROLE_UNSPECIFIED: MongoDBCluster.Host._Role.ValueType  # 0
            PRIMARY: MongoDBCluster.Host._Role.ValueType  # 1
            SECONDARY: MongoDBCluster.Host._Role.ValueType  # 2

        class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...
        ROLE_UNSPECIFIED: MongoDBCluster.Host.Role.ValueType  # 0
        PRIMARY: MongoDBCluster.Host.Role.ValueType  # 1
        SECONDARY: MongoDBCluster.Host.Role.ValueType  # 2

        class _Health:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongoDBCluster.Host._Health.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            HEALTH_UNSPECIFIED: MongoDBCluster.Host._Health.ValueType  # 0
            ALIVE: MongoDBCluster.Host._Health.ValueType  # 1
            DEAD: MongoDBCluster.Host._Health.ValueType  # 2
            DEGRADED: MongoDBCluster.Host._Health.ValueType  # 3

        class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
        HEALTH_UNSPECIFIED: MongoDBCluster.Host.Health.ValueType  # 0
        ALIVE: MongoDBCluster.Host.Health.ValueType  # 1
        DEAD: MongoDBCluster.Host.Health.ValueType  # 2
        DEGRADED: MongoDBCluster.Host.Health.ValueType  # 3

        HOST_FIELD_NUMBER: builtins.int
        PORT_FIELD_NUMBER: builtins.int
        ROLE_FIELD_NUMBER: builtins.int
        HEALTH_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        host: builtins.str
        port: builtins.int
        role: global___MongoDBCluster.Host.Role.ValueType
        health: global___MongoDBCluster.Host.Health.ValueType
        type: global___MongoDBCluster.Host.Type.ValueType
        def __init__(
            self,
            *,
            host: builtins.str = ...,
            port: builtins.int = ...,
            role: global___MongoDBCluster.Host.Role.ValueType = ...,
            health: global___MongoDBCluster.Host.Health.ValueType = ...,
            type: global___MongoDBCluster.Host.Type.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["health", b"health", "host", b"host", "port", b"port", "role", b"role", "type", b"type"]) -> None: ...

    HOSTS_FIELD_NUMBER: builtins.int
    TLS_PARAMS_FIELD_NUMBER: builtins.int
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MongoDBCluster.Host]: ...
    @property
    def tls_params(self) -> yandex.cloud.connectionmanager.v1.common_pb2.TLSParams: ...
    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[global___MongoDBCluster.Host] | None = ...,
        tls_params: yandex.cloud.connectionmanager.v1.common_pb2.TLSParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_params", b"tls_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "tls_params", b"tls_params"]) -> None: ...

global___MongoDBCluster = MongoDBCluster

@typing.final
class MongoDBConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    MANAGED_CLUSTER_ID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    DATABASES_FIELD_NUMBER: builtins.int
    managed_cluster_id: builtins.str
    """When creating/updating Connection, the field "managed_cluster_id" is
    mutually exclusive with "cluster".
    """
    @property
    def cluster(self) -> global___MongoDBCluster:
        """When creating/updating Connection, the field "cluster" is mutually
        exclusive with "managed_cluster_id".
        """

    @property
    def auth(self) -> global___MongoDBAuth: ...
    @property
    def databases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        cluster: global___MongoDBCluster | None = ...,
        managed_cluster_id: builtins.str = ...,
        auth: global___MongoDBAuth | None = ...,
        databases: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster", "databases", b"databases", "managed_cluster_id", b"managed_cluster_id"]) -> None: ...

global___MongoDBConnection = MongoDBConnection



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/searchindex/search_index_file_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/searchindex/search_index_file_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.assistants.v1.searchindex import search_index_file_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_searchindex_dot_search__index__file__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIyandex/cloud/ai/assistants/v1/searchindex/search_index_file_service.proto\x12)yandex.cloud.ai.assistants.v1.searchindex\x1a\x41yandex/cloud/ai/assistants/v1/searchindex/search_index_file.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"\\\n!BatchCreateSearchIndexFileRequest\x12\x18\n\x08\x66ile_ids\x18\x01 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x1d\n\x0fsearch_index_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"o\n\"BatchCreateSearchIndexFileResponse\x12I\n\x05\x66iles\x18\x01 \x03(\x0b\x32:.yandex.cloud.ai.assistants.v1.searchindex.SearchIndexFile\"Q\n\x19GetSearchIndexFileRequest\x12\x15\n\x07\x66ile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\x0fsearch_index_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"c\n\x1bListSearchIndexFilesRequest\x12\x1d\n\x0fsearch_index_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x82\x01\n\x1cListSearchIndexFilesResponse\x12I\n\x05\x66iles\x18\x01 \x03(\x0b\x32:.yandex.cloud.ai.assistants.v1.searchindex.SearchIndexFile\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9a\x05\n\x16SearchIndexFileService\x12\xdd\x01\n\x0b\x42\x61tchCreate\x12L.yandex.cloud.ai.assistants.v1.searchindex.BatchCreateSearchIndexFileRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*$\x12\"BatchCreateSearchIndexFileResponse\x82\xd3\xe4\x93\x02/\"*/assistants/v1/searchIndexFile:batchCreate:\x01*\x12\xcb\x01\n\x03Get\x12\x44.yandex.cloud.ai.assistants.v1.searchindex.GetSearchIndexFileRequest\x1a:.yandex.cloud.ai.assistants.v1.searchindex.SearchIndexFile\"B\x82\xd3\xe4\x93\x02<\x12:/assistants/v1/searchIndexFile/{search_index_id}/{file_id}\x12\xd1\x01\n\x04List\x12\x46.yandex.cloud.ai.assistants.v1.searchindex.ListSearchIndexFilesRequest\x1aG.yandex.cloud.ai.assistants.v1.searchindex.ListSearchIndexFilesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/assistants/v1/searchIndexFile/{search_index_id}B\x8a\x01\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindex'
  _globals['_BATCHCREATESEARCHINDEXFILEREQUEST'].fields_by_name['file_ids']._loaded_options = None
  _globals['_BATCHCREATESEARCHINDEXFILEREQUEST'].fields_by_name['file_ids']._serialized_options = b'\202\3101\002>0'
  _globals['_BATCHCREATESEARCHINDEXFILEREQUEST'].fields_by_name['search_index_id']._loaded_options = None
  _globals['_BATCHCREATESEARCHINDEXFILEREQUEST'].fields_by_name['search_index_id']._serialized_options = b'\350\3071\001'
  _globals['_GETSEARCHINDEXFILEREQUEST'].fields_by_name['file_id']._loaded_options = None
  _globals['_GETSEARCHINDEXFILEREQUEST'].fields_by_name['file_id']._serialized_options = b'\350\3071\001'
  _globals['_GETSEARCHINDEXFILEREQUEST'].fields_by_name['search_index_id']._loaded_options = None
  _globals['_GETSEARCHINDEXFILEREQUEST'].fields_by_name['search_index_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTSEARCHINDEXFILESREQUEST'].fields_by_name['search_index_id']._loaded_options = None
  _globals['_LISTSEARCHINDEXFILESREQUEST'].fields_by_name['search_index_id']._serialized_options = b'\350\3071\001'
  _globals['_SEARCHINDEXFILESERVICE'].methods_by_name['BatchCreate']._loaded_options = None
  _globals['_SEARCHINDEXFILESERVICE'].methods_by_name['BatchCreate']._serialized_options = b'\262\322*$\022\"BatchCreateSearchIndexFileResponse\202\323\344\223\002/\"*/assistants/v1/searchIndexFile:batchCreate:\001*'
  _globals['_SEARCHINDEXFILESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SEARCHINDEXFILESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002<\022:/assistants/v1/searchIndexFile/{search_index_id}/{file_id}'
  _globals['_SEARCHINDEXFILESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SEARCHINDEXFILESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0022\0220/assistants/v1/searchIndexFile/{search_index_id}'
  _globals['_BATCHCREATESEARCHINDEXFILEREQUEST']._serialized_start=322
  _globals['_BATCHCREATESEARCHINDEXFILEREQUEST']._serialized_end=414
  _globals['_BATCHCREATESEARCHINDEXFILERESPONSE']._serialized_start=416
  _globals['_BATCHCREATESEARCHINDEXFILERESPONSE']._serialized_end=527
  _globals['_GETSEARCHINDEXFILEREQUEST']._serialized_start=529
  _globals['_GETSEARCHINDEXFILEREQUEST']._serialized_end=610
  _globals['_LISTSEARCHINDEXFILESREQUEST']._serialized_start=612
  _globals['_LISTSEARCHINDEXFILESREQUEST']._serialized_end=711
  _globals['_LISTSEARCHINDEXFILESRESPONSE']._serialized_start=714
  _globals['_LISTSEARCHINDEXFILESRESPONSE']._serialized_end=844
  _globals['_SEARCHINDEXFILESERVICE']._serialized_start=847
  _globals['_SEARCHINDEXFILESERVICE']._serialized_end=1513
# @@protoc_insertion_point(module_scope)
